import json
import os
import cStringIO as StringIO
import sys
import unittest

from pdfjinja import Attachment, PdfJinja


class PdfJinjaTestCase(unittest.TestCase):

    datadir = os.path.join(os.path.dirname(__file__), "examples")

    def setUp(self):
        pdffile = os.path.join(self.datadir, "sample.pdf")
        jsonfile = os.path.join(self.datadir, "sample.json")
        Attachment.font = "examples/open-sans/regular.ttf"
        self.data = json.loads(open(jsonfile).read())
        self.attachments = [
            Attachment(**kwargs) for kwargs in self.data.pop("attachments")
        ]
        self.pdfjinja = PdfJinja(pdffile)

    def tearDown(self):
        del self.data
        del self.pdfjinja

    def test_render(self):
        output = self.pdfjinja(self.data, self.attachments)
        outfile = StringIO.StringIO()
        output.write(outfile)
        outfile.seek(0)
        self.assertTrue(len(outfile.read()) > 0, "Output PDF is not empty.")


if __name__ == '__main__':
    unittest.main(argv=sys.argv)



#!/usr/bin/env python
""" Package install script. """

import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


f = open(os.path.join(os.path.dirname(__file__), "README.rst"))
readme = f.read()
f.close()

setup(
    name="pdfjinja",
    version="0.0.7",
    author="Ram Mehta",
    author_email="ram.mehta@gmail.com",
    url="http://github.com/rammie/pdfjinja/",
    description='Use jinja templates to fill and sign pdf forms.',
    long_description=readme,
    py_modules=["pdfjinja"],
    entry_points={"console_scripts": ["pdfjinja = pdfjinja:main"]},
    install_requires=[
        "fdfgen==0.11.0",
        "jinja2>=2.8",
        "pdfminer==20140328",
        "pillow>=2.4.0",
        "pyPdf==1.13",
        "reportlab==3.1.44"
    ])
